test/jtreg-ext/requires/VMProps.java
changeset 51753 763aa4d1d596
parent 51341 09cc8813ae51
child 53494 8fd43dacaef7
--- a/test/jtreg-ext/requires/VMProps.java	Fri Sep 14 08:48:36 2018 -0700
+++ b/test/jtreg-ext/requires/VMProps.java	Fri Sep 14 15:32:22 2018 -0400
@@ -84,7 +84,7 @@
         map.put("vm.hasJFR", vmHasJFR());
         map.put("vm.cpu.features", cpuFeatures());
         map.put("vm.rtm.cpu", vmRTMCPU());
-        map.put("vm.rtm.os", vmRTMOS());
+        map.put("vm.rtm.compiler", vmRTMCompiler());
         map.put("vm.aot", vmAOT());
         // vm.cds is true if the VM is compiled with cds support.
         map.put("vm.cds", vmCDS());
@@ -131,8 +131,6 @@
         }
     }
 
-
-
     /**
      * @return VM type value extracted from the "java.vm.name" property.
      */
@@ -301,24 +299,16 @@
     }
 
     /**
      * @return true if VM runs RTM supported OS and false otherwise.
      */
-    protected String vmRTMOS() {
-        boolean isRTMOS = true;
+    protected String vmRTMCompiler() {
+        boolean isRTMCompiler = false;
 
-        if (Platform.isAix()) {
-            // Actually, this works since AIX 7.1.3.30, but os.version property
-            // is set to 7.1.
-            isRTMOS = (Platform.getOsVersionMajor()  > 7) ||
-                      (Platform.getOsVersionMajor() == 7 && Platform.getOsVersionMinor() > 1);
-
-        } else if (Platform.isLinux()) {
-            if (Platform.isPPC()) {
-                isRTMOS = (Platform.getOsVersionMajor()  > 4) ||
-                          (Platform.getOsVersionMajor() == 4 && Platform.getOsVersionMinor() > 1);
-            }
+        if (Compiler.isC2Enabled() &&
+            (Platform.isX86() || Platform.isX64() || Platform.isPPC())) {
+            isRTMCompiler = true;
         }
-        return "" + isRTMOS;
+        return "" + isRTMCompiler;
     }
 
     /**
@@ -301,24 +299,16 @@
 
     /**
-     * @return true if VM runs RTM supported OS and false otherwise.
+     * @return true if compiler in use supports RTM and false otherwise.
      */